@@ -22,7 +22,7 @@ import copy
 from .gvectors import calc_gvectors, symm_eigenvalues, NotSymmetryError, symm_matrix, sortIG
 from .readfiles import Hartree_eV
 from .readfiles import record_abinit
-from .aux import compstr, is_round
+from .utility import compstr, is_round
 from scipy.io import FortranFile as FF
 from lazy_property import LazyProperty
 
@@ -337,7 +337,7 @@ class Kpoint:
     @property
     def NG(self):
         """Getter for the number of plane-waves in current k-point"""
-        return self.ig.shape[0]
+        return self.ig.shape[1]
 
     def __eval_rho_spin(self, degen_thresh):
         """
@@ -1020,7 +1020,7 @@ class Kpoint:
         )
         Nirrep = np.linalg.norm(char.sum(axis=1)) ** 2 / char.shape[0]
         if abs(Nirrep - round(Nirrep)) > 1e-2:
-            print("WARNING - non-integer number of irreps : {0}".format(Nirrep))
+            print("WARNING - non-integer number of states : {0}".format(Nirrep))
         Nirrep = int(round(Nirrep))
         char = np.array(
             [char[:, start:end].sum(axis=1) for start, end in zip(borders, borders[1:])]
@@ -1112,22 +1112,22 @@ class Kpoint:
 
         # Header of the block
         print(
-            "\n\nk-point {0:3d} :{1} \n number of irreps = {2}".format(
+            "\n\nk-point {0:3d} :{1} \n number of states = {2}".format(
                 self.ik0, self.K, Nirrep
             )
         )
-        print("   Energy  | multiplicity |{0} irreps {0}| sym. operations  ".format(s2))
+        print("   Energy  |   degeneracy  |{0} irreps {0}| sym. operations  ".format(s2))
 
         # Symmetry operations
         print(
-            "           |              |{0}        {0}| ".format(s2),
+            "           |               |{0}        {0}| ".format(s2),
             " ".join(s1 + "{0:4d}    ".format(i) + s1 for i in sorted(sym)),
         )
 
         # Energy-levels, irrep's label and traces
         for e, d, ir, ch, ch2 in zip(E, dim, irreps, char, char_refUC):
             # Print characters in calculational unit cell
-            left_str = (" {0:8.4f}  |    {1:5d}     | {2:{3}s} |"
+            left_str = (" {0:8.4f}  |    {1:5d}      | {2:{3}s} |"
                         .format(e - efermi, d, ir, irreplen)
                        )
             right_str = " ".join(
@@ -1319,7 +1319,7 @@ class Kpoint:
                         if i in char
                         else (" " * 7 + "X" * 3 + " " * 8 + "X" * 3)
                     )
-                    for i in range(1, len(symmetries_SG) + 1)
+                    for i in range(1, len(self.symmetries_SG) + 1)
                 )
                 for e, d, ib, j in zip(E, dim, IB, np.arange(len(dim)))
             )
